import { getDataLayer, logDebug } from './utils';
export class AnalyticsPlugin {
    constructor(enabled = true, debug = false) {
        this.enabled = enabled;
        this.debug = debug;
        this.inBrowser = typeof window !== 'undefined';
    }
    trackView(screenName, path) {
        if (typeof window !== 'undefined' && this.enabled) {
            if (this.debug)
                logDebug('trackView', { screenName, path });
            const dataLayer = getDataLayer();
            dataLayer.push({
                'event': 'content-view',
                'content-name': path,
            });
        }
    }
    trackEvent(eventConfig) {
        const { event, category, action, label, value, noninteraction, ...rest } = eventConfig;
        if (this.inBrowser && this.enabled) {
            if (this.debug)
                logDebug('trackEvent', eventConfig);
            const dataLayer = getDataLayer();
            dataLayer.push({
                'event': event || 'interaction',
                'target': category,
                'action': action,
                'target-properties': label,
                'value': value,
                'interaction-type': noninteraction,
                ...rest,
            });
        }
    }
}
//# sourceMappingURL=plugin.js.map